<?php
defined( 'ABSPATH' ) || die();

class STCFQ_Admin_Menu {
	public static function create_menu() {
		if ( current_user_can( 'manage_options' ) ) {
			require_once STCFQ_PLUGIN_DIR_PATH . 'includes/variables.php';
		}

		$messages = add_menu_page(
			esc_html__( 'Contact Form Query', 'contact-form-query' ),
			isset( $messages_count ) && $messages_count ?
				wp_kses(
					/* translators: %d: Number of unanswered messages */
					sprintf( __( 'Contact <span class="awaiting-mod">%d</span>', 'contact-form-query' ), $messages_count ),
					array( 'span' => array( 'class' => array() ) )
				) : esc_html__( 'Contact', 'contact-form-query' ),
			'manage_options',
			'stcfq_messages',
			array( 'STCFQ_Admin_Menu', 'messages' ),
			'dashicons-email',
			27
		);
		add_action( 'admin_print_styles-' . $messages, array( 'STCFQ_Admin_Menu', 'messages_assets' ) );

		$messages_submenu = add_submenu_page( 'stcfq_messages', esc_html__( 'Messages', 'contact-form-query' ), esc_html__( 'Messages', 'contact-form-query' ), 'manage_options', 'stcfq_messages', array( 'STCFQ_Admin_Menu', 'messages' ) );
		add_action( 'admin_print_styles-' . $messages_submenu, array( 'STCFQ_Admin_Menu', 'messages_assets' ) );

		$settings_submenu = add_submenu_page( 'stcfq_messages', esc_html__( 'Settings', 'contact-form-query' ), esc_html__( 'Settings', 'contact-form-query' ), 'manage_options', 'stcfq_settings', array( 'STCFQ_Admin_Menu', 'settings' ) );
		add_action( 'admin_print_styles-' . $settings_submenu, array( 'STCFQ_Admin_Menu', 'settings_assets' ) );
	}

	public static function messages() {
		require_once STCFQ_PLUGIN_DIR_PATH . 'admin/inc/message/route.php';
	}

	public static function messages_assets() {
		wp_enqueue_style( 'stcfq-admin', STCFQ_PLUGIN_URL . 'assets/css/stcfq-admin.css', array(), '1.0.6', 'all' );
		wp_enqueue_script( 'stcfq-admin', STCFQ_PLUGIN_URL . 'assets/js/stcfq-admin.js', array( 'jquery', 'jquery-form' ), '1.0.6', true );
		wp_localize_script( 'stcfq-admin', 'stcfqadminurl', admin_url() );
	}

	public static function settings() {
		require_once STCFQ_PLUGIN_DIR_PATH . 'admin/inc/setting/index.php';
	}

	public static function settings_assets() {
		wp_enqueue_style( 'stcfq-admin', STCFQ_PLUGIN_URL . 'assets/css/stcfq-admin.css', array(), '1.0.6', 'all' );
		wp_enqueue_script( 'stcfq-admin', STCFQ_PLUGIN_URL . 'assets/js/stcfq-admin.js', array( 'jquery', 'jquery-form', 'jquery-ui-sortable' ), '1.0.6', true );
		wp_localize_script( 'stcfq-admin', 'stcfqadminurl', admin_url() );
	}
}
