<?php
defined( 'ABSPATH' ) || die();

wp_enqueue_style( 'stcfq', STCFQ_PLUGIN_URL . 'assets/css/stcfq.css', array(), '1.0.6', 'all' );
wp_enqueue_script( 'stcfq', STCFQ_PLUGIN_URL . 'assets/js/stcfq.js', array( 'jquery', 'jquery-form' ), '1.0.6', true );
wp_localize_script( 'stcfq', 'stcfqadminurl', admin_url() );

require_once STCFQ_PLUGIN_DIR_PATH . 'includes/class-stcfq-helper.php';
$contact_fields = STCFQ_Helper::contact_fields();
$consent_field  = STCFQ_Helper::consent_field();
$submit_button  = STCFQ_Helper::submit_button();

$captcha = get_option( 'stcfq_captcha' );
?>

<form action="<?php echo esc_url( admin_url( 'admin-ajax.php' ) ); ?>" method="post" class="stcfq-save-contact-form">
	<?php $nonce = wp_create_nonce( 'save-contact' ); ?>
	<input type="hidden" name="save-contact" value="<?php echo esc_attr( $nonce ); ?>">
	<input type="hidden" name="action" value="stcfq-save-contact">

	<?php
	foreach ( $contact_fields as $field ) {
		STCFQ_Helper::output_field(
			$field['type'],
			array(
				'name'     => $field['name'],
				'enable'   => $field['enable'],
				'label'    => $field['label'],
				'classes'  => $field['classes'],
				'required' => $field['required'],
			)
		);
	}

	if ( $consent_field['enable'] && ! empty( $consent_field['text'] ) ) {
	?>
	<p>
		<label>
			<input type="checkbox" name="consent" class="stcfq-consent-field <?php echo esc_attr( $consent_field['classes'] ); ?>" value="1">
			<?php echo esc_html( $consent_field['text'] ); ?>
		</label>
	</p>
	<?php
	}
	if ( 'google_recaptcha_v2' === $captcha ) {
		$google_recaptcha_v2 = STCFQ_Helper::google_recaptcha_v2();
		if ( ! empty( $google_recaptcha_v2['site_key'] ) && ! empty( $google_recaptcha_v2['secret_key'] ) ) {
			add_filter( 'script_loader_tag', array( 'STCFQ_Helper', 'add_async_defer_attribute' ), 10, 2 );
			wp_enqueue_script( 'recaptcha-api', 'https://www.google.com/recaptcha/api.js' );
		?>
		<p>
			<div class="g-recaptcha" data-sitekey="<?php echo esc_attr( $google_recaptcha_v2['site_key'] ); ?>" data-theme="<?php echo esc_attr( $google_recaptcha_v2['theme'] ); ?>"></div>
		</p>
		<?php
		}
	}
	?>

	<button type="submit" class="stlsr-save-contact-btn <?php echo esc_attr( $submit_button['classes'] ); ?>"><?php echo esc_html( $submit_button['text'] ); ?></button>
</form>
